@@ -43,6 +43,12 @@ from pocsuite3.lib.core.settings import UNICODE_ENCODING
 from pocsuite3.lib.core.settings import URL_ADDRESS_REGEX
 
 
+try:
+    collectionsAbc = collections.abc
+except AttributeError:
+    collectionsAbc = collections
+
+
 def read_binary(filename):
     content = ''
     with open(filename, 'rb') as f:
@@ -86,9 +92,7 @@ def set_paths(root_path):
     paths.POCSUITE_POCS_PATH = os.path.join(paths.POCSUITE_ROOT_PATH, "pocs")
     paths.USER_POCS_PATH = None
 
-    paths.USER_AGENTS = os.path.join(paths.POCSUITE_DATA_PATH, "user-agents.txt")
     paths.WEAK_PASS = os.path.join(paths.POCSUITE_DATA_PATH, "password-top100.txt")
-    paths.LARGE_WEAK_PASS = os.path.join(paths.POCSUITE_DATA_PATH, "password-top1000.txt")
 
     paths.POCSUITE_HOME_PATH = os.path.expanduser("~")
     _ = os.path.join(paths.POCSUITE_HOME_PATH, ".pocsuite")
@@ -102,7 +106,7 @@ def set_paths(root_path):
     paths.POCSUITE_TMP_PATH = os.path.join(_, "tmp")
     paths.POCSUITE_RC_PATH = os.path.join(paths.POCSUITE_HOME_PATH, ".pocsuiterc")
     paths.POCSUITE_OUTPUT_PATH = paths.get("POCSUITE_OUTPUT_PATH", os.path.join(_, "output"))
-    paths.SHELLCODES_DEV_PATH = os.path.join(paths.POCSUITE_ROOT_PATH, "shellcodes", "tools")
+    paths.SHELLCODES_DEV_PATH = os.path.join(paths.POCSUITE_TMP_PATH, "tools")
 
 
 def banner():
@@ -997,7 +1001,7 @@ def get_host_ipv6(dst='2001:db8::'):
     return s.getsockname()[0]
 
 
-class OrderedSet(collections.OrderedDict, collections.MutableSet):
+class OrderedSet(collections.OrderedDict, collectionsAbc.MutableSet):
 
     def add(self, e):
         self[e] = None
