@@ -1,5 +1,5 @@
 import urllib
-
+import getpass
 from configparser import ConfigParser
 from pocsuite3.lib.core.data import logger
 from pocsuite3.lib.core.data import paths
@@ -8,26 +8,27 @@ from pocsuite3.lib.request import requests
 
 class Shodan():
     def __init__(self, conf_path=paths.POCSUITE_RC_PATH, token=None):
-        self.headers = None
+        self.headers = {'User-Agent': 'curl/7.80.0'}
         self.credits = 0
         self.conf_path = conf_path
+        self.token = token
 
         if self.conf_path:
             self.parser = ConfigParser()
             self.parser.read(self.conf_path)
             try:
-                self.token = self.parser.get("Shodan", 'Token')
+                self.token = self.token or self.parser.get("Shodan", 'Token')
             except Exception:
                 pass
 
-        if token:
-            self.token = token
         self.check_token()
 
     def token_is_available(self):
         if self.token:
             try:
-                resp = requests.get('https://api.shodan.io/account/profile?key={0}'.format(self.token))
+                resp = requests.get(
+                    'https://api.shodan.io/account/profile?key={0}'.format(self.token), headers=self.headers)
+                logger.info(resp.text)
                 if resp and resp.status_code == 200 and "member" in resp.json():
                     return True
             except Exception as ex:
@@ -37,9 +38,9 @@ class Shodan():
     def check_token(self):
         if self.token_is_available():
             return True
-        else:
 
-            new_token = input("Shodan API Token:")
+        while True:
+            new_token = getpass.getpass("Shodan API Token: (input will hidden)")
             self.token = new_token
             if self.token_is_available():
                 self.write_conf()
@@ -47,7 +48,6 @@ class Shodan():
             else:
                 logger.error("The shodan api token is incorrect. "
                              "Please enter the correct api token.")
-                self.check_token()
 
     def write_conf(self):
         if not self.parser.has_section("Shodan"):
@@ -60,7 +60,8 @@ class Shodan():
 
     def get_resource_info(self):
         try:
-            resp = requests.get('https://api.shodan.io/account/profile?key={0}'.format(self.token))
+            resp = requests.get(
+                'https://api.shodan.io/account/profile?key={0}'.format(self.token), headers=self.headers)
             if resp and resp.status_code == 200 and 'credits' in resp.json():
                 content = resp.json()
                 self.credits = content['credits']
@@ -70,15 +71,15 @@ class Shodan():
         return False
 
     def search(self, dork, pages=1, resource='host'):
+        # shodan rest api only support host search
+        resource = 'host'
         search_result = set()
         try:
             for page in range(1, pages + 1):
-                url = "https://api.shodan.io/shodan/{0}/search?key={1}&query={2}&page={3}".format(resource,
-                                                                                                  self.token,
-                                                                                                  urllib.parse.quote(
-                                                                                                      dork),
-                                                                                                  page)
-                resp = requests.get(url)
+                url = (
+                    "https://api.shodan.io/shodan/{0}/search?key={1}&query={2}&page={3}"
+                ).format(resource, self.token, urllib.parse.quote(dork), page)
+                resp = requests.get(url, headers=self.headers)
                 if resp and resp.status_code == 200 and "total" in resp.json():
                     content = resp.json()
                     for match in content['matches']:
